==> haskell-vector-th-unbox-0.2.1.4-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-vector-th-unbox/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.4
id: vector-th-unbox-0.2.1.4-1139d5b6f0cb29dac6aff26bf8525b7e
key: vecto_LdUF8URAUIRCaUgShQB17f
license: BSD3
copyright: © 2012−2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
author: Liyang HU <vector-th-unbox@liyang.hu>
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-th-unbox-0.2.1.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-th-unbox-0.2.1.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-th-unbox-0.2.1.4
hs-libraries: HSvector-th-unbox-0.2.1.4-LdUF8URAUIRCaUgShQB17f
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-th-unbox-0.2.1.5-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-vector-th-unbox/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.5
id: vector-th-unbox-0.2.1.5-8f7270dc4460c13d7b9488d6341118f7
key: vecto_6RM2VcClkzlGSIppxsSFFI
license: BSD3
copyright: © 2012−2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
author: Liyang HU <vector-th-unbox@liyang.hu>
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-th-unbox-0.2.1.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-th-unbox-0.2.1.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-th-unbox-0.2.1.5
hs-libraries: HSvector-th-unbox-0.2.1.5-6RM2VcClkzlGSIppxsSFFI
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
